@@ -101,7 +101,7 @@ setClassUnion(name="prob.class", members=c("matrix", "numeric", "data.frame"))
 #' with dimensions `nsim` x `length(CAL_mids)`.
 #' @slot CAL_bins The values delimiting the length bins for the catch-at-length data. Vector. Non-negative real numbers
 #' @slot CAL_mids The values of the mid-points of the length bins. Optional, calculated from `CAL_bins` if not entered. Vector. Non-negative real numbers.
-#' @slot CAL Catch-at-length data. An array with dimensions nsim x nyears x length(CAL_mids). Non-negative integers
+#' @slot CAL Catch-at-length data. An array with dimensions nsim x nyears x length(CAL_mids). Non-negative integers. By default the CAL data will be the retained lengths (i.e, not including discards). If `OM@control$CAL =="removals"` then the CAL data will include all removals (retained + discards).
 #'
 #' @slot Dep Stock depletion SSB(current)/SSB(unfished). Vector nsim long. Fraction.
 #' @slot CV_Dep Coefficient of variation in current stock depletion. Vector nsim long. Positive real numbers
@@ -913,8 +913,8 @@ setMethod("initialize", "OM", function(.Object, Stock=NULL, Fleet=MSEtool::Gener
 #'  \item Landings: Landings (biomass); array dimensions `c(nsim, nyears, nareas)`
 #'  \item Discards: Discards (biomass); array dimensions `c(nsim, nyears, nareas)`
 #'  \item Find: Historical fishing mortality (scale-free); matrix dimensions `c(nsim, nyears)`
-#'  \item RecDev: Recruitment deviations (historical and projection);
-#'  matrix dimensions `c(nsim, nyears+proyears+maxage)`
+#'  \item RecDev: Recruitment deviations (historical and projection); matrix dimensions `c(nsim, nyears+proyears+maxage)`
+#'  \item SPR: Named list with Equilibrium and Dynamic SPR (both matrices iwth dimensions `c(nsim, nyears)`)
 #'  \item Unfished_Equilibrium: A named list with unfished equilibrium numbers and biomass-at-age
 #' }
 #'
@@ -932,6 +932,12 @@ setMethod("initialize", "OM", function(.Object, Stock=NULL, Fleet=MSEtool::Gener
 #'      \item SSBMSY: Spawning stock biomass corresponding with asymptotic MSY
 #'      \item BMSY: total biomass corresponding with asymptotic MSY
 #'      \item VBMSY: Vulnerable biomass corresponding with asymptotic MSY
+#'      \item F01: Fishing mortality where the change in yield per recruit is 10% of that at F = 0
+#'      \item Fmax: Fishing mortality that maximizes yield per recruit
+#'      \item F_SPR: Fishing mortality corresponding to spawning potential ratio of 20 - 60% in increments of 5%; array dimensions \code{c(nsim, 9, nyears+proyears)}
+#'      \item Fcrash: Fishing mortality corresponding to the recruits-per-spawner at the origin of the stock-recruit relationship
+#'      \item Fmed: Fishing mortality corresponding to the median recruits-per-spawner in the historical period
+#'      \item SPRcrash: SPR corresponding to the recruits-per-spawner at the origin of the stock-recruit relationship
 #'    }
 #'    \item Dynamic_Unfished: A named list with dynamic unfished reference points for each simulation and year:
 #'    \itemize{
@@ -1089,11 +1095,11 @@ setMethod("show", signature = (object="PMobj"), function(object) {
     for (sl in sls) {
       r <- match(sl, sls)
       slval <- slot(object, sl)
-      if (class(slval) == "array" & length(slval)>0) {
+      if ('array' %in% class(slval) & length(slval)>0 & length(dim(slval))>2) {
         df[r,2] <- 'array'
-      } else if (class(slval) == "matrix" & length(slval)>0) {
+      } else if ('matrix' %in% class(slval) & length(slval)>0) {
         df[r,2] <- 'matrix'
-      } else if (length(slval) > 0 & class(slval) != "call") {
+      } else if (length(slval) > 0 & ! 'call' %in% class(slval)) {
         df[r,2] <- slval
       } else {
         df[r, 2] <- 'not defined'
@@ -1493,7 +1499,7 @@ setMethod("summary",
 
               df1$Year <- as.numeric(df1$Year)
 
-              yr.n <- df1 %>% dplyr::group_by(Year) %>% dplyr::summarise(n=sum(Freq))
+              yr.n <- df1 %>% dplyr::group_by(Year) %>% dplyr::summarise(n=sum(Freq, na.rm=T))
               yr.ind <- yr.n %>% dplyr::filter(n>0) %>% dplyr::select(Year)
 
               Years <- object@Year
