@@ -920,46 +920,91 @@ COSEWIC_Hplot<-function(MSEobj,syear=2017,qcol=rgb(0.4,0.8,0.95), quants=c(0.05,
 
 #' Subset an OM cpars slot
 #'
-#' Subset the custom parameters of an operating model
+#' Subset the custom parameters of an operating model by simulation and projection years 
 #'
 #' @param OM An object of class OM
 #' @param sims A logical vector of length \code{OM@@nsim} to either retain (TRUE) or remove (FALSE).
 #' Alternatively, a numeric vector indicating which simulations (from 1 to nsim) to keep.
+#' @param proyears If provided, a numeric to reduce the number of projection years (must be less than \code{OM@@proyears}).
 #' @return An object of class OM
+#' @seealso \link{Sub} for MSE objects, \link{SubOM} for OM components.
 #' @author T. Carruthers, Q. Huynh
 #' @export SubCpars
-SubCpars<-function(OM, sims = 1:OM@nsim) {
-  if(!length(OM@cpars)) return(OM)
-
+SubCpars<-function(OM, sims = 1:OM@nsim, proyears = OM@proyears) {
+  
+  # Reduce the number of simulations
+  nsim_full <- OM@nsim
   if(is.numeric(sims)) {
-    sims2 <- logical(OM@nsim)
+    sims2 <- logical(nsim_full)
     sims2[sims] <- TRUE
-  } else if(is.logical(sims) && length(sims) == OM@nsim) {
+  } else if(is.logical(sims) && length(sims) == nsim_full) {
     sims2 <- sims
-  } else stop("Logical vector sims need to be of length ", OM@nsim)
-
-  if(any(!sims2)) {
+  } else stop("Logical vector sims need to be of length ", nsim_full)
+  
+  if(any(!sims2) && sum(sims2) < nsim_full) {
     message("Removing simulations: ", paste0(which(!sims2), collapse = " "))
-    cpars <- OM@cpars
-
-    subset_function <- function(xx, sims, cpars) {
-      x <- cpars[[xx]]
-      if(any(xx == c("CAL_bins", "MPA", "plusgroup", "CAL_binsmid", "binWidth", "AddIunits", "Wa", "Wb", "Data"))) {
-        return(x)
-      } else if(is.matrix(x)) {
-        return(x[sims, , drop = FALSE])
-      } else if(is.array(x)) {
-        if(length(dim(x)) == 3) return(x[sims, , , drop = FALSE])
-        if(length(dim(x)) == 4) return(x[sims, , , , drop = FALSE])
-        if(length(dim(x)) == 5) return(x[sims, , , , , drop = FALSE])
-      } else if(length(x) == OM@nsim) {
-        return(x[sims])
-      } else return(x)
-    }
-    OM@cpars <- lapply(names(cpars), subset_function, sims = sims2, cpars = cpars) %>% structure(names = names(cpars))
-    OM@nsim <- sum(sims2)
-
+    OM@nsim <- sum(sims2)      
     message("Set OM@nsim = ", OM@nsim)
+    
+    if(length(OM@cpars)) {
+      cpars <- OM@cpars
+      
+      subset_function <- function(xx, sims, cpars) {
+        x <- cpars[[xx]]
+        if(any(xx == c("CAL_bins", "MPA", "plusgroup", "CAL_binsmid", "binWidth", "AddIunits", "Wa", "Wb", "Data"))) {
+          return(x)
+        } else if(is.matrix(x)) {
+          return(x[sims, , drop = FALSE])
+        } else if(is.array(x)) {
+          if(length(dim(x)) == 3) return(x[sims, , , drop = FALSE])
+          if(length(dim(x)) == 4) return(x[sims, , , , drop = FALSE])
+          if(length(dim(x)) == 5) return(x[sims, , , , , drop = FALSE])
+        } else if(length(x) == length(sims)) {
+          return(x[sims])
+        } else return(x)
+      }
+      
+      OM@cpars <- lapply(names(cpars), subset_function, sims = sims2, cpars = cpars) %>% structure(names = names(cpars))
+    }
+  }
+  
+  # Reduce the number of projection years
+  proyears_full <- OM@proyears
+  if(proyears < proyears_full) {
+    message("Reducing the number of projection years from ", proyears_full, " to ", proyears)
+    OM@proyears <- proyears
+    
+    if(length(OM@cpars)) {
+      cpars_p <- OM@cpars
+      yr_diff <- proyears_full - proyears
+      
+      subset_proyears_function <- function(xx, yr_diff, cpars) {
+        x <- cpars[[xx]]
+        if(xx %in% c("Asize", "Find", "AddIbeta", "Data")) { # Matrices or arrays without projection year dimensions
+          return(x)
+        } else if(xx == "MPA") {
+          yr_remove <- (nrow(x) - yr_diff + 1):nrow(x)
+          return(x[-yr_remove, ])
+        } else if(is.matrix(x)) {
+          yr_remove <- (ncol(x) - yr_diff + 1):ncol(x)
+          return(x[, -yr_remove])
+        } else if(is.array(x)) {
+          
+          ldim <- length(dim(x))
+          yr_remove <- (dim(x)[ldim] - yr_diff + 1):dim(x)[ldim]
+          
+          if(ldim == 3) return(x[, , -yr_remove, drop = FALSE])
+          if(ldim == 4) return(x[, , , -yr_remove, drop = FALSE])
+          if(ldim == 5) return(x[, , , , -yr_remove, drop = FALSE])
+        } else {
+          return(x)
+        }
+      }
+      
+      OM@cpars <- lapply(names(cpars_p), subset_proyears_function, yr_diff = yr_diff, cpars = cpars_p) %>% structure(names = names(cpars_p))
+    }
+  } else if(proyears > proyears_full) {
+    message("Number of specified projection years is greater than OM@proyears. Nothing done.")
   }
 
   return(OM)
