@@ -10,6 +10,11 @@ getDataList<-function(MSElist,mm){
     DataList[[ss]]<-new('list')
     for (ff in 1:length(MSElist[[ss]])) {
       DataList[[ss]][[ff]] <-MSElist[[ss]][[ff]][[mm]]
+      
+      # drop stockpars etc from Misc slot
+      DataList[[ss]][[ff]]@Misc$StockPars <- NULL
+      DataList[[ss]][[ff]]@Misc$FleetPars <- NULL
+      DataList[[ss]][[ff]]@Misc$ReferencePoints <- NULL
     }
   }
   DataList
